<?php
/**
 * Elementor Widget
 * @package smartwp
 * @since 1.0.0
 */

namespace Elementor;
class smartwp_about_us extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'smartwp-about-us-widget';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'About Us', 'smartwp' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-product-info';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'smartwp_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'General Settings', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter title.', 'smartwp' ),
				'default'     => esc_html__('What We Can Do?','smartwp')
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label'       => esc_html__( 'Sub Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'enter sub title.', 'smartwp' ),
				'default'     => __('Our Company Application <br> Core <span class="theme-color">Features</span>','smartwp')
			]
		);	

		$this->add_control(
			'content',
			[
				'label'       => esc_html__( 'Content', 'smartwp' ),
				'type'        => Controls_Manager::WYSIWYG,
				'description' => esc_html__( 'enter content.', 'smartwp' ),
				]
		);

		$this->add_control( 'about_items', [
			'label'       => esc_html__( 'About Item', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'default'     => [
				[
					'items' => esc_html__( 'A business is an organization where people', 'smartwp' ),
				]
			],
			'fields'      => [

				[
					'name'        => 'items',
					'label'       => esc_html__( 'About', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
					'description' => esc_html__( 'Enter About Item', 'smartwp' )
				]

			],
			'title_field' => "{{name}}"
		] );

		$this->add_control(
	   		 'image-one',
	      	[
	          'label' => esc_html__( 'About Image One', 'smartwp' ),
	          'type'  => Controls_Manager::MEDIA,
				'dynamic' => [
				'active' => true,
			   ],
	    	]
	    );

	    $this->add_control(
	   		 'image-two',
	      	[
	          'label' => esc_html__( 'About Image Two', 'smartwp' ),
	          'type'  => Controls_Manager::MEDIA,
				'dynamic' => [
				'active' => true,
			   ],
	    	]
	    );

	    $this->add_control(
			'imagecapation',
			[
				'label'       => esc_html__( 'Image Caption', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter image caption.', 'smartwp' ),
				'default'     => esc_html__('“Business is the activity of makingone\'s living or making money','smartwp')
			]
		);


		$this->end_controls_section();
	}

	/**
	 * Render Elementor widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		?>	
		<!-- Core feature Section Start -->
    <section class="core-feature p-tb-120">
    	<div class="container">
    		<div class="row align-items-center">
    			<!-- Tile Gallery -->
    			<div class="col-lg-6">
    				<div class="tile-gallery-wrap m-b-70 position-relative">
    					<img src="<?php echo esc_html( $settings['image-one']['url'] ); ?>" alt="about smartwp">
    					<img class="img-2" src="<?php echo esc_html( $settings['image-two']['url'] ); ?>" alt="about smartwp">
    					<div class="tile-content">
    						<p><?php echo wp_kses_post( $settings['imagecapation'] ); ?></p>
    					</div>
    				</div>
    			</div>
    			<div class="col-lg-6">
    				<div class="core-content">
    					<h3 class="fs-30 lh-45 m-b-35"> <span class="d-block fs-18"><?php echo esc_html( $settings['title'] ); ?></span> <?php echo wp_kses_post( $settings['subtitle'] ); ?></h3>
    					   <?php echo wp_kses_post( $settings['content'] ); ?>

    					<div class="core-feature-list m-t-40">
    						<ul>
    							<?php foreach(  $settings['about_items'] as $item ) : ?>
    							<li><img src="<?php echo get_template_directory_uri(); ?>/img/icon/check-mark-2.png" alt="smartwp"><?php echo esc_html( $item['items'] ); ?></li>
    							<?php endforeach; ?>
    						</ul>
    					</div>
    				</div>
    			</div>
    		</div>
    	</div>
    </section>
	<!-- Core feature Section End -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new smartwp_about_us() );