<?php

/**
 * Elementor widget
 * @package smartwp
 * @since 1.0.0
 * */

namespace Elementor;
class smartwp_client extends Widget_Base{
	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'client-widget';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('Client','smartwp');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-divider';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['smartwp_widgets'];
	}
	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
		protected function _register_controls() {

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'General Settings', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter title text.', 'smartwp' ),
				'default'     => esc_html__('Our happy Clients','smartwp')
			]
		);

		$this->add_control(
			'sub-title',
			[
				'label'       => esc_html__( 'Sub Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'From ban king and insurance to wealth management and on securities distrib', 'smartwp' ),
			]
		);	

		$this->add_control( 'testimonial_items', [
			'label'       => esc_html__( 'Testimonial Items', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'default'     => [
				[
					'name'        => esc_html__( 'Anton Morris', 'smartwp' ),
					'designation' => esc_html__( 'Web Developer', 'smartwp' ),
				]
			],
			'fields'      => [
				[
					'name'        => 'name',
					'label'       => esc_html__( 'Name', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'description' => esc_html__( 'Enter name', 'smartwp' )
				],
				[
					'name'        => 'designation',
					'label'       => esc_html__( 'Designation', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'description' => esc_html__( 'Enter relation', 'smartwp' )
				],
				[
					'name'        => 'content',
					'label'       => esc_html__( 'Content', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
					'description' => esc_html__( 'Enter relation', 'smartwp' )
				],            
				[
					'name'        => 'image',
					'label'       => esc_html__( 'Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload image', 'smartwp' )
				],
				

			],
			'title_field' => "{{name}}"
		] );
		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();

		?>
	              <!-- Testimonial Start -->
    <section class="testimonial-section p-tb-120" id="testimonial">
        <div class="container">
            <!-- Section Title -->
            <div class="section-title m-b-60 text-center">
                <h3><?php echo esc_html( $settings['title'] ); ?></h3>
                <p><?php echo esc_html( $settings['sub-title'] ); ?></p>
            </div>
            <div class="row">
                <div class="col-lg-6">
                    <div class="testimonial-dots"></div>
                </div>
                <div class="col-lg-6 no-padding">
                    <div class="testimonial-slider" id="testimonialActive">
                    	<?php foreach( $settings['testimonial_items'] as $item ) : ?>
                        <!-- Single Testimonial -->
                        <div class="single-testimonial" data-thumb="<?php echo esc_url( $item['image']['url'] ); ?>">
                            <div class="testimonial-img">
                                <img src="<?php echo esc_url( $item['image']['url'] ); ?>" alt="testimonial">
                            </div>
                            <div class="testimonial-content text-center">
                                <h6 class="fs-16 m-b-10"> <?php echo esc_html( $item['name'] ); ?></h6>
                                <p class="m-b-25"><?php echo esc_html( $item['designation'] ); ?></p>
                                <p><?php echo esc_html( $item['content'] ); ?></p>
                            </div>
                        </div>
                    	<?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- Testimonial End -->
		<?php
	}
}
plugin::instance()->widgets_manager->register_widget_type(new smartwp_client());