<?php

/**
 * Elementor widget
 * @package Quray
 * @since 1.0.0
 * */

namespace Elementor;
class smartwp_testimonial extends Widget_Base{
	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'testimonial-widget';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('Testimonial','smartwp');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-divider';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['smartwp_widgets'];
	}
	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
		protected function _register_controls() {

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'General Settings', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter title text.', 'smartwp' ),
				'default'     => esc_html__('TESTIMONIALS','smartwp')
			]
		);

		$this->add_control(
			'sub-title',
			[
				'label'       => esc_html__( 'Sub Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'enter Sub title text.', 'smartwp' ),
			]
		);	

		$this->add_control( 'testimonial_member_items', [
			'label'       => esc_html__( 'Testimonial Members', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'default'     => [
				[
					'name'        => esc_html__( 'Anton Morris', 'smartwp' ),
					'designation' => esc_html__( 'Web Developer', 'smartwp' ),
				]
			],
			'fields'      => [
				[
					'name'        => 'name',
					'label'       => esc_html__( 'Name', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'description' => esc_html__( 'Enter name', 'smartwp' )
				],
				[
					'name'        => 'designation',
					'label'       => esc_html__( 'Designation', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'description' => esc_html__( 'Enter relation', 'smartwp' )
				],
				[
					'name'        => 'content',
					'label'       => esc_html__( 'Content', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'description' => esc_html__( 'Enter relation', 'smartwp' )
				],             
				[
					'name'        => 'image',
					'label'       => esc_html__( 'Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload image', 'smartwp' )
				],

			],
			'title_field' => "{{name}}"
		] );
		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();

		$column           = $settings['column'];
		$testimonial_items = $settings['testimonial_member_items'];

		?>
	        <!--====== TESTIMONIALS PART START ======-->
		    <section class="testimonils-area bg_cover" style="background-image: url(assets/images/testimonials-map-bg.jpg)">
		        <div class="container">
		            <div class="row justify-content-center">
		                <div class="col-lg-6">
		                    <div class="section-title text-center">
		                        <span><?php echo esc_html( $settings['title'] ); ?></span>
		                        <h6 class="title"><?php echo wp_kses_post( $settings['sub-title'] ); ?></h6>
		                    </div>
		                </div>
		            </div>
		            <div class="row testimonials-active">
		            	<?php 
		            		foreach( $testimonial_items as $item ) : 
		            			$image_id = $item['image']['id'];
								$image_url = wp_get_attachment_image_src( $image_id, 'full', false );

		            		?>
			                <div class="col-lg-4">
			                    <div class="single-testimonils">
			                        <div class="testimonils-item">
			                            <p><?php echo esc_html( $item['content'] ); ?></p>
			                            <i class="fas fa-quote-right"></i>
			                        </div>
			                        <div class="testimonils-info d-flex align-items-center ml-70 mt-10">
			                            <div class="test-thumb">
			                                <img src="<?php echo esc_url( $image_url[0] ); ?>" alt="info">
			                            </div>
			                            <div class="test-content pl-15">
			                                <h5 class="title"><?php echo esc_html( $item[ 'name' ] ); ?></h5>
			                                <p><?php echo esc_html( $item['designation'] ); ?></p>
			                            </div>
			                        </div>
			                    </div>
			                </div>
		            	<?php endforeach; ?>
		            </div>
		        </div>
		    </section>
		    <!--====== TESTIMONIALS PART ENDS ======-->
		<?php
	}
}
plugin::instance()->widgets_manager->register_widget_type(new smartwp_testimonial());