<?php
/**
 * Elementor Widget
 * @package Smartwp
 * @since 1.0.0
 */

namespace Elementor;
class smartwp_work_history extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'smartwp-work';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Work History', 'smartwp' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-product-info';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'smartwp_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'General Settings', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Secti;on Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'enter title text.', 'smartwp' ),
				'default'	  => esc_html__( 'Our Work History', 'smartwp' )
			]
		);		

		$this->end_controls_section();
		

		$this->start_controls_section(
			'service_section',
			[
				'label' => esc_html__( 'Work Item', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control( 'work_history_items', [
			'label'       => esc_html__( 'Work Item', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'default'     => [
				[
					'number' => esc_html__( '981K', 'smartwp' ),
					'name' => esc_html__( 'Powerful Options', 'smartwp' ),
					'type' => esc_html__( 'Sometime Accident', 'smartwp' ),
				]
			],
			'fields'      => [

				[
					'name'        => 'number',
					'label'       => esc_html__( 'Work Name', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'description' => esc_html__( '981K', 'smartwp' )
				],
				[
					'name'        => 'name',
					'label'       => esc_html__( 'name', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
				],
				[
					'name'        => 'type',
					'label'       => esc_html__( 'Type', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
				],

			],
			'title_field' => "{{name}}"
		] );

		$this->add_control(
	   		 'bgimage',
	      	[
	          'label' => esc_html__( 'Backgrond Image', 'smartwp' ),
	          'type'  => Controls_Manager::MEDIA,
				'dynamic' => [
				'active' => true,
			   ],
	    	]
	    );

		$this->end_controls_section();

	}

	/**
	 * Render Elementor widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$work_history_items = $settings['work_history_items'];

		?>	
		<!-- Counter UP section Start -->
		<section class="counterup-section position-relative bg-img-c p-tb-90" style="background-image: url( <?php echo esc_url( $settings['bgimage']['url'] ); ?> );">
			<div class="container">
				<h3 class="fs-30 m-b-45"><?php echo esc_html( $settings['title'] ); ?></h3>
				<div class="row">
					<?php foreach( $work_history_items as $item ): ?>
						<div class="col-lg-3 col-md-6 col-12">
							<div class="single-counter-box trans-03 text-center p-all-30">
								<h2 class="fs-40 lh-24 theme-color m-b-30 trans-03"><span class="counter"><?php echo esc_html( $item['number'] ); ?></span></h2>
								<p class="fs-20 fw-700"><?php echo esc_html( $item['name'] ); ?><span class="theme-color trans-03 d-block fs-14 fw-400"><?php echo esc_html( $item['type'] ); ?></span></p>
							</div>
						</div>
					<?php endforeach; ?>
				</div>
			</div>	
		</section>
		<!-- Counter UP section End -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new smartwp_work_history() );